# -*- coding: utf8 -*-
from django.conf import settings
from django.core.mail import send_mail
from django.template.loader import render_to_string
from datetime import date, timedelta

from formations.models import Formation


def run():
    # On récupère la liste des formations qui nous intéressent
    demain = date.today() + timedelta(days=1)
    formations_en_cours = Formation.objects.filter(
        date_heure__year=demain.year,
        date_heure__month=demain.month,
        date_heure__day=demain.day,
    )

    for formation in formations_en_cours:
        inscrits = formation.inscrits.all()
        respo = formation.responsable

        # On prépare le mail
        mail_from = settings.DEFAULT_FROM_EMAIL
        mail_to = [respo.email]
        sujet_mail = f"Formation {formation.nom}"
        c = {
            "prenom": respo.first_name,
            "date_heure": formation.date_heure,
            "titre_formation": formation.nom,
            "lieu": formation.lieu,
            "nb_inscrits": len(inscrits),
            "inscrits": inscrits,
        }
        contenu_mail = render_to_string("formations/mail_form.txt", c)

        # Et on envoie !
        send_mail(sujet_mail, contenu_mail, mail_from, mail_to, fail_silently=False)
